# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/orchestrator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2
from cogment.api import environment_pb2 as cogment_dot_api_dot_environment__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/orchestrator.proto',
  package='cogmentAPI',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x63ogment/api/orchestrator.proto\x12\ncogmentAPI\x1a\x18\x63ogment/api/common.proto\x1a\x1d\x63ogment/api/environment.proto\"i\n\x11TrialStartRequest\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.cogmentAPI.TrialConfig\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x1a\n\x12trial_id_requested\x18\x03 \x01(\t\"#\n\x0fTrialStartReply\x12\x10\n\x08trial_id\x18\x01 \x01(\t\"1\n\x15TerminateTrialRequest\x12\x18\n\x10hard_termination\x18\x01 \x01(\x08\"\x15\n\x13TerminateTrialReply\"J\n\x10TrialInfoRequest\x12\x1e\n\x16get_latest_observation\x18\x01 \x01(\x08\x12\x16\n\x0eget_actor_list\x18\x02 \x01(\x08\"\xe8\x01\n\tTrialInfo\x12\x10\n\x08trial_id\x18\x01 \x01(\t\x12%\n\x05state\x18\x02 \x01(\x0e\x32\x16.cogmentAPI.TrialState\x12\x10\n\x08\x65nv_name\x18\x03 \x01(\t\x12\x0f\n\x07tick_id\x18\x04 \x01(\x04\x12\x16\n\x0etrial_duration\x18\x05 \x01(\x06\x12\x36\n\x12latest_observation\x18\x06 \x01(\x0b\x32\x1a.cogmentAPI.ObservationSet\x12/\n\x0f\x61\x63tors_in_trial\x18\x07 \x03(\x0b\x32\x16.cogmentAPI.TrialActor\"6\n\x0eTrialInfoReply\x12$\n\x05trial\x18\x01 \x03(\x0b\x32\x15.cogmentAPI.TrialInfo\":\n\x10TrialListRequest\x12&\n\x06\x66ilter\x18\x01 \x03(\x0e\x32\x16.cogmentAPI.TrialState\"I\n\x0eTrialListEntry\x12\x10\n\x08trial_id\x18\x01 \x01(\t\x12%\n\x05state\x18\x02 \x01(\x0e\x32\x16.cogmentAPI.TrialState2\x91\x03\n\x10TrialLifecycleSP\x12J\n\nStartTrial\x12\x1d.cogmentAPI.TrialStartRequest\x1a\x1b.cogmentAPI.TrialStartReply\"\x00\x12V\n\x0eTerminateTrial\x12!.cogmentAPI.TerminateTrialRequest\x1a\x1f.cogmentAPI.TerminateTrialReply\"\x00\x12J\n\x0cGetTrialInfo\x12\x1c.cogmentAPI.TrialInfoRequest\x1a\x1a.cogmentAPI.TrialInfoReply\"\x00\x12K\n\x0bWatchTrials\x12\x1c.cogmentAPI.TrialListRequest\x1a\x1a.cogmentAPI.TrialListEntry\"\x00\x30\x01\x12@\n\x07Version\x12\x1a.cogmentAPI.VersionRequest\x1a\x17.cogmentAPI.VersionInfo\"\x00\x32\xa4\x01\n\rClientActorSP\x12Q\n\x08RunTrial\x12\x1f.cogmentAPI.ActorRunTrialOutput\x1a\x1e.cogmentAPI.ActorRunTrialInput\"\x00(\x01\x30\x01\x12@\n\x07Version\x12\x1a.cogmentAPI.VersionRequest\x1a\x17.cogmentAPI.VersionInfo\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,cogment_dot_api_dot_environment__pb2.DESCRIPTOR,])




_TRIALSTARTREQUEST = _descriptor.Descriptor(
  name='TrialStartRequest',
  full_name='cogmentAPI.TrialStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='cogmentAPI.TrialStartRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='cogmentAPI.TrialStartRequest.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trial_id_requested', full_name='cogmentAPI.TrialStartRequest.trial_id_requested', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=208,
)


_TRIALSTARTREPLY = _descriptor.Descriptor(
  name='TrialStartReply',
  full_name='cogmentAPI.TrialStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogmentAPI.TrialStartReply.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=245,
)


_TERMINATETRIALREQUEST = _descriptor.Descriptor(
  name='TerminateTrialRequest',
  full_name='cogmentAPI.TerminateTrialRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hard_termination', full_name='cogmentAPI.TerminateTrialRequest.hard_termination', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=296,
)


_TERMINATETRIALREPLY = _descriptor.Descriptor(
  name='TerminateTrialReply',
  full_name='cogmentAPI.TerminateTrialReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=319,
)


_TRIALINFOREQUEST = _descriptor.Descriptor(
  name='TrialInfoRequest',
  full_name='cogmentAPI.TrialInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='get_latest_observation', full_name='cogmentAPI.TrialInfoRequest.get_latest_observation', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='get_actor_list', full_name='cogmentAPI.TrialInfoRequest.get_actor_list', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=395,
)


_TRIALINFO = _descriptor.Descriptor(
  name='TrialInfo',
  full_name='cogmentAPI.TrialInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogmentAPI.TrialInfo.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.TrialInfo.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_name', full_name='cogmentAPI.TrialInfo.env_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.TrialInfo.tick_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trial_duration', full_name='cogmentAPI.TrialInfo.trial_duration', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_observation', full_name='cogmentAPI.TrialInfo.latest_observation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actors_in_trial', full_name='cogmentAPI.TrialInfo.actors_in_trial', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=630,
)


_TRIALINFOREPLY = _descriptor.Descriptor(
  name='TrialInfoReply',
  full_name='cogmentAPI.TrialInfoReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial', full_name='cogmentAPI.TrialInfoReply.trial', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=686,
)


_TRIALLISTREQUEST = _descriptor.Descriptor(
  name='TrialListRequest',
  full_name='cogmentAPI.TrialListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='cogmentAPI.TrialListRequest.filter', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=746,
)


_TRIALLISTENTRY = _descriptor.Descriptor(
  name='TrialListEntry',
  full_name='cogmentAPI.TrialListEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogmentAPI.TrialListEntry.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.TrialListEntry.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=821,
)

_TRIALSTARTREQUEST.fields_by_name['config'].message_type = cogment_dot_api_dot_common__pb2._TRIALCONFIG
_TRIALINFO.fields_by_name['state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
_TRIALINFO.fields_by_name['latest_observation'].message_type = cogment_dot_api_dot_environment__pb2._OBSERVATIONSET
_TRIALINFO.fields_by_name['actors_in_trial'].message_type = cogment_dot_api_dot_common__pb2._TRIALACTOR
_TRIALINFOREPLY.fields_by_name['trial'].message_type = _TRIALINFO
_TRIALLISTREQUEST.fields_by_name['filter'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
_TRIALLISTENTRY.fields_by_name['state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
DESCRIPTOR.message_types_by_name['TrialStartRequest'] = _TRIALSTARTREQUEST
DESCRIPTOR.message_types_by_name['TrialStartReply'] = _TRIALSTARTREPLY
DESCRIPTOR.message_types_by_name['TerminateTrialRequest'] = _TERMINATETRIALREQUEST
DESCRIPTOR.message_types_by_name['TerminateTrialReply'] = _TERMINATETRIALREPLY
DESCRIPTOR.message_types_by_name['TrialInfoRequest'] = _TRIALINFOREQUEST
DESCRIPTOR.message_types_by_name['TrialInfo'] = _TRIALINFO
DESCRIPTOR.message_types_by_name['TrialInfoReply'] = _TRIALINFOREPLY
DESCRIPTOR.message_types_by_name['TrialListRequest'] = _TRIALLISTREQUEST
DESCRIPTOR.message_types_by_name['TrialListEntry'] = _TRIALLISTENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TrialStartRequest = _reflection.GeneratedProtocolMessageType('TrialStartRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIALSTARTREQUEST,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialStartRequest)
  })
_sym_db.RegisterMessage(TrialStartRequest)

TrialStartReply = _reflection.GeneratedProtocolMessageType('TrialStartReply', (_message.Message,), {
  'DESCRIPTOR' : _TRIALSTARTREPLY,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialStartReply)
  })
_sym_db.RegisterMessage(TrialStartReply)

TerminateTrialRequest = _reflection.GeneratedProtocolMessageType('TerminateTrialRequest', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATETRIALREQUEST,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TerminateTrialRequest)
  })
_sym_db.RegisterMessage(TerminateTrialRequest)

TerminateTrialReply = _reflection.GeneratedProtocolMessageType('TerminateTrialReply', (_message.Message,), {
  'DESCRIPTOR' : _TERMINATETRIALREPLY,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TerminateTrialReply)
  })
_sym_db.RegisterMessage(TerminateTrialReply)

TrialInfoRequest = _reflection.GeneratedProtocolMessageType('TrialInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIALINFOREQUEST,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialInfoRequest)
  })
_sym_db.RegisterMessage(TrialInfoRequest)

TrialInfo = _reflection.GeneratedProtocolMessageType('TrialInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRIALINFO,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialInfo)
  })
_sym_db.RegisterMessage(TrialInfo)

TrialInfoReply = _reflection.GeneratedProtocolMessageType('TrialInfoReply', (_message.Message,), {
  'DESCRIPTOR' : _TRIALINFOREPLY,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialInfoReply)
  })
_sym_db.RegisterMessage(TrialInfoReply)

TrialListRequest = _reflection.GeneratedProtocolMessageType('TrialListRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIALLISTREQUEST,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialListRequest)
  })
_sym_db.RegisterMessage(TrialListRequest)

TrialListEntry = _reflection.GeneratedProtocolMessageType('TrialListEntry', (_message.Message,), {
  'DESCRIPTOR' : _TRIALLISTENTRY,
  '__module__' : 'cogment.api.orchestrator_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.TrialListEntry)
  })
_sym_db.RegisterMessage(TrialListEntry)



_TRIALLIFECYCLESP = _descriptor.ServiceDescriptor(
  name='TrialLifecycleSP',
  full_name='cogmentAPI.TrialLifecycleSP',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=824,
  serialized_end=1225,
  methods=[
  _descriptor.MethodDescriptor(
    name='StartTrial',
    full_name='cogmentAPI.TrialLifecycleSP.StartTrial',
    index=0,
    containing_service=None,
    input_type=_TRIALSTARTREQUEST,
    output_type=_TRIALSTARTREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TerminateTrial',
    full_name='cogmentAPI.TrialLifecycleSP.TerminateTrial',
    index=1,
    containing_service=None,
    input_type=_TERMINATETRIALREQUEST,
    output_type=_TERMINATETRIALREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTrialInfo',
    full_name='cogmentAPI.TrialLifecycleSP.GetTrialInfo',
    index=2,
    containing_service=None,
    input_type=_TRIALINFOREQUEST,
    output_type=_TRIALINFOREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchTrials',
    full_name='cogmentAPI.TrialLifecycleSP.WatchTrials',
    index=3,
    containing_service=None,
    input_type=_TRIALLISTREQUEST,
    output_type=_TRIALLISTENTRY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogmentAPI.TrialLifecycleSP.Version',
    index=4,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRIALLIFECYCLESP)

DESCRIPTOR.services_by_name['TrialLifecycleSP'] = _TRIALLIFECYCLESP


_CLIENTACTORSP = _descriptor.ServiceDescriptor(
  name='ClientActorSP',
  full_name='cogmentAPI.ClientActorSP',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1228,
  serialized_end=1392,
  methods=[
  _descriptor.MethodDescriptor(
    name='RunTrial',
    full_name='cogmentAPI.ClientActorSP.RunTrial',
    index=0,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._ACTORRUNTRIALOUTPUT,
    output_type=cogment_dot_api_dot_common__pb2._ACTORRUNTRIALINPUT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Version',
    full_name='cogmentAPI.ClientActorSP.Version',
    index=1,
    containing_service=None,
    input_type=cogment_dot_api_dot_common__pb2._VERSIONREQUEST,
    output_type=cogment_dot_api_dot_common__pb2._VERSIONINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLIENTACTORSP)

DESCRIPTOR.services_by_name['ClientActorSP'] = _CLIENTACTORSP

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogment/api/trial_datastore.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogment.api import common_pb2 as cogment_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogment/api/trial_datastore.proto',
  package='cogmentAPI',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!cogment/api/trial_datastore.proto\x12\ncogmentAPI\x1a\x18\x63ogment/api/common.proto\"g\n\x15RetrieveTrialsRequest\x12\x11\n\ttrial_ids\x18\x01 \x03(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\r\x12\x14\n\x0ctrials_count\x18\x03 \x01(\r\x12\x14\n\x0ctrial_handle\x18\x04 \x01(\t\"b\n\x13RetrieveTrialsReply\x12\x30\n\x0btrial_infos\x18\x01 \x03(\x0b\x32\x1b.cogmentAPI.StoredTrialInfo\x12\x19\n\x11next_trial_handle\x18\x02 \x01(\t\"\xba\x01\n\x16RetrieveSamplesRequest\x12\x11\n\ttrial_ids\x18\x01 \x03(\t\x12\x13\n\x0b\x61\x63tor_names\x18\x02 \x03(\t\x12\x15\n\ractor_classes\x18\x03 \x03(\t\x12\x1d\n\x15\x61\x63tor_implementations\x18\x04 \x03(\t\x12\x42\n\x16selected_sample_fields\x18\x05 \x03(\x0e\x32\".cogmentAPI.StoredTrialSampleField\"J\n\x13RetrieveSampleReply\x12\x33\n\x0ctrial_sample\x18\x01 \x01(\x0b\x32\x1d.cogmentAPI.StoredTrialSample\"(\n\x13\x44\x65leteTrialsRequest\x12\x11\n\ttrial_ids\x18\x01 \x03(\t\"\x13\n\x11\x44\x65leteTrialsReply\"Q\n\x0f\x41\x64\x64TrialRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12-\n\x0ctrial_params\x18\x02 \x01(\x0b\x32\x17.cogmentAPI.TrialParams\"\x0f\n\rAddTrialReply\"G\n\x10\x41\x64\x64SampleRequest\x12\x33\n\x0ctrial_sample\x18\x01 \x01(\x0b\x32\x1d.cogmentAPI.StoredTrialSample\"\x11\n\x0f\x41\x64\x64SamplesReply\"\xa0\x01\n\x0fStoredTrialInfo\x12\x10\n\x08trial_id\x18\x01 \x01(\t\x12*\n\nlast_state\x18\x02 \x01(\x0e\x32\x16.cogmentAPI.TrialState\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x15\n\rsamples_count\x18\x04 \x01(\r\x12\'\n\x06params\x18\x05 \x01(\x0b\x32\x17.cogmentAPI.TrialParams\"\xce\x01\n\x11StoredTrialSample\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08trial_id\x18\x02 \x01(\t\x12\x0f\n\x07tick_id\x18\x03 \x01(\x04\x12\x11\n\ttimestamp\x18\x04 \x01(\x06\x12%\n\x05state\x18\x05 \x01(\x0e\x32\x16.cogmentAPI.TrialState\x12\x39\n\ractor_samples\x18\x06 \x03(\x0b\x32\".cogmentAPI.StoredTrialActorSample\x12\x10\n\x08payloads\x18\x07 \x03(\x0c\"\x9d\x03\n\x16StoredTrialActorSample\x12\r\n\x05\x61\x63tor\x18\x01 \x01(\r\x12\x18\n\x0bobservation\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x13\n\x06\x61\x63tion\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x13\n\x06reward\x18\x04 \x01(\x02H\x02\x88\x01\x01\x12\x42\n\x10received_rewards\x18\x06 \x03(\x0b\x32(.cogmentAPI.StoredTrialActorSampleReward\x12>\n\x0csent_rewards\x18\x07 \x03(\x0b\x32(.cogmentAPI.StoredTrialActorSampleReward\x12\x44\n\x11received_messages\x18\x08 \x03(\x0b\x32).cogmentAPI.StoredTrialActorSampleMessage\x12@\n\rsent_messages\x18\t \x03(\x0b\x32).cogmentAPI.StoredTrialActorSampleMessageB\x0e\n\x0c_observationB\t\n\x07_actionB\t\n\x07_reward\"\x8a\x01\n\x1cStoredTrialActorSampleReward\x12\x0e\n\x06sender\x18\x01 \x01(\x05\x12\x10\n\x08receiver\x18\x02 \x01(\x05\x12\x0e\n\x06reward\x18\x04 \x01(\x02\x12\x12\n\nconfidence\x18\x05 \x01(\x02\x12\x16\n\tuser_data\x18\x06 \x01(\rH\x00\x88\x01\x01\x42\x0c\n\n_user_data\"R\n\x1dStoredTrialActorSampleMessage\x12\x0e\n\x06sender\x18\x01 \x01(\x05\x12\x10\n\x08receiver\x18\x02 \x01(\x05\x12\x0f\n\x07payload\x18\x03 \x01(\r*\xf0\x02\n\x16StoredTrialSampleField\x12%\n!STORED_TRIAL_SAMPLE_FIELD_UNKNOWN\x10\x00\x12)\n%STORED_TRIAL_SAMPLE_FIELD_OBSERVATION\x10\x01\x12$\n STORED_TRIAL_SAMPLE_FIELD_ACTION\x10\x02\x12$\n STORED_TRIAL_SAMPLE_FIELD_REWARD\x10\x03\x12.\n*STORED_TRIAL_SAMPLE_FIELD_RECEIVED_REWARDS\x10\x04\x12*\n&STORED_TRIAL_SAMPLE_FIELD_SENT_REWARDS\x10\x05\x12/\n+STORED_TRIAL_SAMPLE_FIELD_RECEIVED_MESSAGES\x10\x06\x12+\n\'STORED_TRIAL_SAMPLE_FIELD_SENT_MESSAGES\x10\x07\x32\xaa\x03\n\x10TrialDatastoreSP\x12V\n\x0eRetrieveTrials\x12!.cogmentAPI.RetrieveTrialsRequest\x1a\x1f.cogmentAPI.RetrieveTrialsReply\"\x00\x12Z\n\x0fRetrieveSamples\x12\".cogmentAPI.RetrieveSamplesRequest\x1a\x1f.cogmentAPI.RetrieveSampleReply\"\x00\x30\x01\x12\x44\n\x08\x41\x64\x64Trial\x12\x1b.cogmentAPI.AddTrialRequest\x1a\x19.cogmentAPI.AddTrialReply\"\x00\x12J\n\tAddSample\x12\x1c.cogmentAPI.AddSampleRequest\x1a\x1b.cogmentAPI.AddSamplesReply\"\x00(\x01\x12P\n\x0c\x44\x65leteTrials\x12\x1f.cogmentAPI.DeleteTrialsRequest\x1a\x1d.cogmentAPI.DeleteTrialsReply\"\x00\x62\x06proto3'
  ,
  dependencies=[cogment_dot_api_dot_common__pb2.DESCRIPTOR,])

_STOREDTRIALSAMPLEFIELD = _descriptor.EnumDescriptor(
  name='StoredTrialSampleField',
  full_name='cogmentAPI.StoredTrialSampleField',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STORED_TRIAL_SAMPLE_FIELD_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORED_TRIAL_SAMPLE_FIELD_OBSERVATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORED_TRIAL_SAMPLE_FIELD_ACTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORED_TRIAL_SAMPLE_FIELD_REWARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORED_TRIAL_SAMPLE_FIELD_RECEIVED_REWARDS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORED_TRIAL_SAMPLE_FIELD_SENT_REWARDS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORED_TRIAL_SAMPLE_FIELD_RECEIVED_MESSAGES', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STORED_TRIAL_SAMPLE_FIELD_SENT_MESSAGES', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1814,
  serialized_end=2182,
)
_sym_db.RegisterEnumDescriptor(_STOREDTRIALSAMPLEFIELD)

StoredTrialSampleField = enum_type_wrapper.EnumTypeWrapper(_STOREDTRIALSAMPLEFIELD)
STORED_TRIAL_SAMPLE_FIELD_UNKNOWN = 0
STORED_TRIAL_SAMPLE_FIELD_OBSERVATION = 1
STORED_TRIAL_SAMPLE_FIELD_ACTION = 2
STORED_TRIAL_SAMPLE_FIELD_REWARD = 3
STORED_TRIAL_SAMPLE_FIELD_RECEIVED_REWARDS = 4
STORED_TRIAL_SAMPLE_FIELD_SENT_REWARDS = 5
STORED_TRIAL_SAMPLE_FIELD_RECEIVED_MESSAGES = 6
STORED_TRIAL_SAMPLE_FIELD_SENT_MESSAGES = 7



_RETRIEVETRIALSREQUEST = _descriptor.Descriptor(
  name='RetrieveTrialsRequest',
  full_name='cogmentAPI.RetrieveTrialsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_ids', full_name='cogmentAPI.RetrieveTrialsRequest.trial_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='cogmentAPI.RetrieveTrialsRequest.timeout', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trials_count', full_name='cogmentAPI.RetrieveTrialsRequest.trials_count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trial_handle', full_name='cogmentAPI.RetrieveTrialsRequest.trial_handle', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=178,
)


_RETRIEVETRIALSREPLY = _descriptor.Descriptor(
  name='RetrieveTrialsReply',
  full_name='cogmentAPI.RetrieveTrialsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_infos', full_name='cogmentAPI.RetrieveTrialsReply.trial_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_trial_handle', full_name='cogmentAPI.RetrieveTrialsReply.next_trial_handle', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=278,
)


_RETRIEVESAMPLESREQUEST = _descriptor.Descriptor(
  name='RetrieveSamplesRequest',
  full_name='cogmentAPI.RetrieveSamplesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_ids', full_name='cogmentAPI.RetrieveSamplesRequest.trial_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_names', full_name='cogmentAPI.RetrieveSamplesRequest.actor_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_classes', full_name='cogmentAPI.RetrieveSamplesRequest.actor_classes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_implementations', full_name='cogmentAPI.RetrieveSamplesRequest.actor_implementations', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selected_sample_fields', full_name='cogmentAPI.RetrieveSamplesRequest.selected_sample_fields', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=467,
)


_RETRIEVESAMPLEREPLY = _descriptor.Descriptor(
  name='RetrieveSampleReply',
  full_name='cogmentAPI.RetrieveSampleReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_sample', full_name='cogmentAPI.RetrieveSampleReply.trial_sample', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=543,
)


_DELETETRIALSREQUEST = _descriptor.Descriptor(
  name='DeleteTrialsRequest',
  full_name='cogmentAPI.DeleteTrialsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_ids', full_name='cogmentAPI.DeleteTrialsRequest.trial_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=545,
  serialized_end=585,
)


_DELETETRIALSREPLY = _descriptor.Descriptor(
  name='DeleteTrialsReply',
  full_name='cogmentAPI.DeleteTrialsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=587,
  serialized_end=606,
)


_ADDTRIALREQUEST = _descriptor.Descriptor(
  name='AddTrialRequest',
  full_name='cogmentAPI.AddTrialRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='cogmentAPI.AddTrialRequest.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trial_params', full_name='cogmentAPI.AddTrialRequest.trial_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=608,
  serialized_end=689,
)


_ADDTRIALREPLY = _descriptor.Descriptor(
  name='AddTrialReply',
  full_name='cogmentAPI.AddTrialReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=706,
)


_ADDSAMPLEREQUEST = _descriptor.Descriptor(
  name='AddSampleRequest',
  full_name='cogmentAPI.AddSampleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_sample', full_name='cogmentAPI.AddSampleRequest.trial_sample', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=779,
)


_ADDSAMPLESREPLY = _descriptor.Descriptor(
  name='AddSamplesReply',
  full_name='cogmentAPI.AddSamplesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=781,
  serialized_end=798,
)


_STOREDTRIALINFO = _descriptor.Descriptor(
  name='StoredTrialInfo',
  full_name='cogmentAPI.StoredTrialInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogmentAPI.StoredTrialInfo.trial_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_state', full_name='cogmentAPI.StoredTrialInfo.last_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='cogmentAPI.StoredTrialInfo.user_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samples_count', full_name='cogmentAPI.StoredTrialInfo.samples_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='cogmentAPI.StoredTrialInfo.params', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=961,
)


_STOREDTRIALSAMPLE = _descriptor.Descriptor(
  name='StoredTrialSample',
  full_name='cogmentAPI.StoredTrialSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='cogmentAPI.StoredTrialSample.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trial_id', full_name='cogmentAPI.StoredTrialSample.trial_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='cogmentAPI.StoredTrialSample.tick_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='cogmentAPI.StoredTrialSample.timestamp', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='cogmentAPI.StoredTrialSample.state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_samples', full_name='cogmentAPI.StoredTrialSample.actor_samples', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payloads', full_name='cogmentAPI.StoredTrialSample.payloads', index=6,
      number=7, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=1170,
)


_STOREDTRIALACTORSAMPLE = _descriptor.Descriptor(
  name='StoredTrialActorSample',
  full_name='cogmentAPI.StoredTrialActorSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor', full_name='cogmentAPI.StoredTrialActorSample.actor', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observation', full_name='cogmentAPI.StoredTrialActorSample.observation', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='cogmentAPI.StoredTrialActorSample.action', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward', full_name='cogmentAPI.StoredTrialActorSample.reward', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received_rewards', full_name='cogmentAPI.StoredTrialActorSample.received_rewards', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sent_rewards', full_name='cogmentAPI.StoredTrialActorSample.sent_rewards', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received_messages', full_name='cogmentAPI.StoredTrialActorSample.received_messages', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sent_messages', full_name='cogmentAPI.StoredTrialActorSample.sent_messages', index=7,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_observation', full_name='cogmentAPI.StoredTrialActorSample._observation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_action', full_name='cogmentAPI.StoredTrialActorSample._action',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_reward', full_name='cogmentAPI.StoredTrialActorSample._reward',
      index=2, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1173,
  serialized_end=1586,
)


_STOREDTRIALACTORSAMPLEREWARD = _descriptor.Descriptor(
  name='StoredTrialActorSampleReward',
  full_name='cogmentAPI.StoredTrialActorSampleReward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='cogmentAPI.StoredTrialActorSampleReward.sender', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='cogmentAPI.StoredTrialActorSampleReward.receiver', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward', full_name='cogmentAPI.StoredTrialActorSampleReward.reward', index=2,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='cogmentAPI.StoredTrialActorSampleReward.confidence', index=3,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='cogmentAPI.StoredTrialActorSampleReward.user_data', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_user_data', full_name='cogmentAPI.StoredTrialActorSampleReward._user_data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1589,
  serialized_end=1727,
)


_STOREDTRIALACTORSAMPLEMESSAGE = _descriptor.Descriptor(
  name='StoredTrialActorSampleMessage',
  full_name='cogmentAPI.StoredTrialActorSampleMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='cogmentAPI.StoredTrialActorSampleMessage.sender', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='cogmentAPI.StoredTrialActorSampleMessage.receiver', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='cogmentAPI.StoredTrialActorSampleMessage.payload', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1729,
  serialized_end=1811,
)

_RETRIEVETRIALSREPLY.fields_by_name['trial_infos'].message_type = _STOREDTRIALINFO
_RETRIEVESAMPLESREQUEST.fields_by_name['selected_sample_fields'].enum_type = _STOREDTRIALSAMPLEFIELD
_RETRIEVESAMPLEREPLY.fields_by_name['trial_sample'].message_type = _STOREDTRIALSAMPLE
_ADDTRIALREQUEST.fields_by_name['trial_params'].message_type = cogment_dot_api_dot_common__pb2._TRIALPARAMS
_ADDSAMPLEREQUEST.fields_by_name['trial_sample'].message_type = _STOREDTRIALSAMPLE
_STOREDTRIALINFO.fields_by_name['last_state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
_STOREDTRIALINFO.fields_by_name['params'].message_type = cogment_dot_api_dot_common__pb2._TRIALPARAMS
_STOREDTRIALSAMPLE.fields_by_name['state'].enum_type = cogment_dot_api_dot_common__pb2._TRIALSTATE
_STOREDTRIALSAMPLE.fields_by_name['actor_samples'].message_type = _STOREDTRIALACTORSAMPLE
_STOREDTRIALACTORSAMPLE.fields_by_name['received_rewards'].message_type = _STOREDTRIALACTORSAMPLEREWARD
_STOREDTRIALACTORSAMPLE.fields_by_name['sent_rewards'].message_type = _STOREDTRIALACTORSAMPLEREWARD
_STOREDTRIALACTORSAMPLE.fields_by_name['received_messages'].message_type = _STOREDTRIALACTORSAMPLEMESSAGE
_STOREDTRIALACTORSAMPLE.fields_by_name['sent_messages'].message_type = _STOREDTRIALACTORSAMPLEMESSAGE
_STOREDTRIALACTORSAMPLE.oneofs_by_name['_observation'].fields.append(
  _STOREDTRIALACTORSAMPLE.fields_by_name['observation'])
_STOREDTRIALACTORSAMPLE.fields_by_name['observation'].containing_oneof = _STOREDTRIALACTORSAMPLE.oneofs_by_name['_observation']
_STOREDTRIALACTORSAMPLE.oneofs_by_name['_action'].fields.append(
  _STOREDTRIALACTORSAMPLE.fields_by_name['action'])
_STOREDTRIALACTORSAMPLE.fields_by_name['action'].containing_oneof = _STOREDTRIALACTORSAMPLE.oneofs_by_name['_action']
_STOREDTRIALACTORSAMPLE.oneofs_by_name['_reward'].fields.append(
  _STOREDTRIALACTORSAMPLE.fields_by_name['reward'])
_STOREDTRIALACTORSAMPLE.fields_by_name['reward'].containing_oneof = _STOREDTRIALACTORSAMPLE.oneofs_by_name['_reward']
_STOREDTRIALACTORSAMPLEREWARD.oneofs_by_name['_user_data'].fields.append(
  _STOREDTRIALACTORSAMPLEREWARD.fields_by_name['user_data'])
_STOREDTRIALACTORSAMPLEREWARD.fields_by_name['user_data'].containing_oneof = _STOREDTRIALACTORSAMPLEREWARD.oneofs_by_name['_user_data']
DESCRIPTOR.message_types_by_name['RetrieveTrialsRequest'] = _RETRIEVETRIALSREQUEST
DESCRIPTOR.message_types_by_name['RetrieveTrialsReply'] = _RETRIEVETRIALSREPLY
DESCRIPTOR.message_types_by_name['RetrieveSamplesRequest'] = _RETRIEVESAMPLESREQUEST
DESCRIPTOR.message_types_by_name['RetrieveSampleReply'] = _RETRIEVESAMPLEREPLY
DESCRIPTOR.message_types_by_name['DeleteTrialsRequest'] = _DELETETRIALSREQUEST
DESCRIPTOR.message_types_by_name['DeleteTrialsReply'] = _DELETETRIALSREPLY
DESCRIPTOR.message_types_by_name['AddTrialRequest'] = _ADDTRIALREQUEST
DESCRIPTOR.message_types_by_name['AddTrialReply'] = _ADDTRIALREPLY
DESCRIPTOR.message_types_by_name['AddSampleRequest'] = _ADDSAMPLEREQUEST
DESCRIPTOR.message_types_by_name['AddSamplesReply'] = _ADDSAMPLESREPLY
DESCRIPTOR.message_types_by_name['StoredTrialInfo'] = _STOREDTRIALINFO
DESCRIPTOR.message_types_by_name['StoredTrialSample'] = _STOREDTRIALSAMPLE
DESCRIPTOR.message_types_by_name['StoredTrialActorSample'] = _STOREDTRIALACTORSAMPLE
DESCRIPTOR.message_types_by_name['StoredTrialActorSampleReward'] = _STOREDTRIALACTORSAMPLEREWARD
DESCRIPTOR.message_types_by_name['StoredTrialActorSampleMessage'] = _STOREDTRIALACTORSAMPLEMESSAGE
DESCRIPTOR.enum_types_by_name['StoredTrialSampleField'] = _STOREDTRIALSAMPLEFIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RetrieveTrialsRequest = _reflection.GeneratedProtocolMessageType('RetrieveTrialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVETRIALSREQUEST,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RetrieveTrialsRequest)
  })
_sym_db.RegisterMessage(RetrieveTrialsRequest)

RetrieveTrialsReply = _reflection.GeneratedProtocolMessageType('RetrieveTrialsReply', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVETRIALSREPLY,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RetrieveTrialsReply)
  })
_sym_db.RegisterMessage(RetrieveTrialsReply)

RetrieveSamplesRequest = _reflection.GeneratedProtocolMessageType('RetrieveSamplesRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVESAMPLESREQUEST,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RetrieveSamplesRequest)
  })
_sym_db.RegisterMessage(RetrieveSamplesRequest)

RetrieveSampleReply = _reflection.GeneratedProtocolMessageType('RetrieveSampleReply', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVESAMPLEREPLY,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.RetrieveSampleReply)
  })
_sym_db.RegisterMessage(RetrieveSampleReply)

DeleteTrialsRequest = _reflection.GeneratedProtocolMessageType('DeleteTrialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETRIALSREQUEST,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.DeleteTrialsRequest)
  })
_sym_db.RegisterMessage(DeleteTrialsRequest)

DeleteTrialsReply = _reflection.GeneratedProtocolMessageType('DeleteTrialsReply', (_message.Message,), {
  'DESCRIPTOR' : _DELETETRIALSREPLY,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.DeleteTrialsReply)
  })
_sym_db.RegisterMessage(DeleteTrialsReply)

AddTrialRequest = _reflection.GeneratedProtocolMessageType('AddTrialRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDTRIALREQUEST,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.AddTrialRequest)
  })
_sym_db.RegisterMessage(AddTrialRequest)

AddTrialReply = _reflection.GeneratedProtocolMessageType('AddTrialReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDTRIALREPLY,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.AddTrialReply)
  })
_sym_db.RegisterMessage(AddTrialReply)

AddSampleRequest = _reflection.GeneratedProtocolMessageType('AddSampleRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDSAMPLEREQUEST,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.AddSampleRequest)
  })
_sym_db.RegisterMessage(AddSampleRequest)

AddSamplesReply = _reflection.GeneratedProtocolMessageType('AddSamplesReply', (_message.Message,), {
  'DESCRIPTOR' : _ADDSAMPLESREPLY,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.AddSamplesReply)
  })
_sym_db.RegisterMessage(AddSamplesReply)

StoredTrialInfo = _reflection.GeneratedProtocolMessageType('StoredTrialInfo', (_message.Message,), {
  'DESCRIPTOR' : _STOREDTRIALINFO,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.StoredTrialInfo)
  })
_sym_db.RegisterMessage(StoredTrialInfo)

StoredTrialSample = _reflection.GeneratedProtocolMessageType('StoredTrialSample', (_message.Message,), {
  'DESCRIPTOR' : _STOREDTRIALSAMPLE,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.StoredTrialSample)
  })
_sym_db.RegisterMessage(StoredTrialSample)

StoredTrialActorSample = _reflection.GeneratedProtocolMessageType('StoredTrialActorSample', (_message.Message,), {
  'DESCRIPTOR' : _STOREDTRIALACTORSAMPLE,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.StoredTrialActorSample)
  })
_sym_db.RegisterMessage(StoredTrialActorSample)

StoredTrialActorSampleReward = _reflection.GeneratedProtocolMessageType('StoredTrialActorSampleReward', (_message.Message,), {
  'DESCRIPTOR' : _STOREDTRIALACTORSAMPLEREWARD,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.StoredTrialActorSampleReward)
  })
_sym_db.RegisterMessage(StoredTrialActorSampleReward)

StoredTrialActorSampleMessage = _reflection.GeneratedProtocolMessageType('StoredTrialActorSampleMessage', (_message.Message,), {
  'DESCRIPTOR' : _STOREDTRIALACTORSAMPLEMESSAGE,
  '__module__' : 'cogment.api.trial_datastore_pb2'
  # @@protoc_insertion_point(class_scope:cogmentAPI.StoredTrialActorSampleMessage)
  })
_sym_db.RegisterMessage(StoredTrialActorSampleMessage)



_TRIALDATASTORESP = _descriptor.ServiceDescriptor(
  name='TrialDatastoreSP',
  full_name='cogmentAPI.TrialDatastoreSP',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2185,
  serialized_end=2611,
  methods=[
  _descriptor.MethodDescriptor(
    name='RetrieveTrials',
    full_name='cogmentAPI.TrialDatastoreSP.RetrieveTrials',
    index=0,
    containing_service=None,
    input_type=_RETRIEVETRIALSREQUEST,
    output_type=_RETRIEVETRIALSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrieveSamples',
    full_name='cogmentAPI.TrialDatastoreSP.RetrieveSamples',
    index=1,
    containing_service=None,
    input_type=_RETRIEVESAMPLESREQUEST,
    output_type=_RETRIEVESAMPLEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddTrial',
    full_name='cogmentAPI.TrialDatastoreSP.AddTrial',
    index=2,
    containing_service=None,
    input_type=_ADDTRIALREQUEST,
    output_type=_ADDTRIALREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddSample',
    full_name='cogmentAPI.TrialDatastoreSP.AddSample',
    index=3,
    containing_service=None,
    input_type=_ADDSAMPLEREQUEST,
    output_type=_ADDSAMPLESREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTrials',
    full_name='cogmentAPI.TrialDatastoreSP.DeleteTrials',
    index=4,
    containing_service=None,
    input_type=_DELETETRIALSREQUEST,
    output_type=_DELETETRIALSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRIALDATASTORESP)

DESCRIPTOR.services_by_name['TrialDatastoreSP'] = _TRIALDATASTORESP

# @@protoc_insertion_point(module_scope)
